@@ -11,38 +11,35 @@ __all__ = ["Atom", "Lattice", "concat_lattices"]
 class Atom:
     """An entry within a :class:`Lattice`.
 
-    The Atom has three propertiers. An element from the periodic table, fractional coordinates in form of a
-    :class:`~crystally.core.vectors.FractionalVector` and a sublattice name.
+    The Atom has two propertiers. An element and fractional coordinates ion form f a
+    :class:`~crystally.core.vectors.PeriodicVector`.
 
     :param element: string of element name
     :param position: fractional position of the atom
-    :param sublattice: name of the sublattice the atom is in
     :return: Atom object
     """
 
-    def __init__(self, element: str ="", position=(0, 0, 0), sublattice: str=""):
+    def __init__(self, element: str = "", position=(0, 0, 0)):
         self.element = str(element)
-        self._position = FractionalVector(position)
-        self.sublattice = str(sublattice)
+        if len(position) != 3:
+            raise ValueError("Position needs three entries!")
+        self._position = PeriodicVector(position)
 
     def __str__(self):
         string_representation = "Atom:"
         string_representation += f" {self.element:4s} "
-        string_representation += f" [{', '.join([f'{coord:13.10f}' for coord in self.position.value])}] "
-        string_representation += f" {self.sublattice:8s}"
+        string_representation += f"[ {', '.join([f'{coord:.10f}' for coord in self.position.value])} ]"
         return string_representation
 
     def __repr__(self):
         rep = "Atom("
-        rep += repr(self.element)    + ","
-        rep += repr(self.position)   + ","
-        rep += repr(self.sublattice) + ")"
+        rep += repr(self.element) + ", "
+        rep += repr(self.position.value.tolist()) + ")"
         return rep
 
     def __eq__(self, other):
         return self.element == other.element        \
-           and self.position == other.position      \
-           and self.sublattice == other.sublattice
+           and self.position == other.position
 
     @property
     def position(self):
@@ -50,7 +47,9 @@ class Atom:
 
     @position.setter
     def position(self, new_position):
-        self._position = FractionalVector(new_position)
+        if len(new_position) != 3:
+            raise ValueError("Position needs three entries!")
+        self._position = PeriodicVector(new_position)
 
 
 class Lattice:
@@ -85,8 +84,11 @@ class Lattice:
 
     def __repr__(self):
         rep = "Lattice("
-        rep += repr(self.vectors.tolist())  + ","
-        rep += repr(self.atoms)             + ")"
+        rep += repr(self.vectors.tolist()) + ", \n"
+        rep += "["
+        for atom in self:
+            rep += repr(atom) + ", \n"
+        rep += "])"
         return rep
 
     def __getitem__(self, item):
@@ -104,25 +106,18 @@ class Lattice:
 
     @vectors.setter
     def vectors(self, vec):
+        new = np.array(vec)
+        if new.shape != (3, 3):
+            raise ValueError("The lattice vectors have to be represented as a 3x3 matrix.")
         self._vectors = np.array(vec)
 
     @property
-    def size(self):
+    def volume(self):
         """ Calculates the volume of the lattice.
 
         :return: volume of lattice
         """
-        if self.vectors.ndim == 1:
-            return np.linalg.norm(self.vectors)
-        elif self.vectors.ndim == 2:
-            if len(self.vectors) == 1:
-                return np.linalg.norm(self.vectors[0])
-            elif len(self.vectors) == 2:
-                return self.vectors[0].dot(self.vectors[1])
-            elif len(self.vectors) == 3:
-                return np.cross(self.vectors[0], self.vectors[1]).dot(self.vectors[2])
-        else:
-            raise NotImplemented("Size property is not compatible with lattice vectors!")
+        return np.cross(self.vectors[0], self.vectors[1]).dot(self.vectors[2])
 
     def sort(self, key=None, tolerance=None):
         """ Sort the lattice with a given key.
@@ -148,47 +143,25 @@ class Lattice:
             self.atoms.sort(key=lambda atom: atom.element)
         elif key == "position":
             self.atoms.sort(key=lambda atom: self.distance(atom, [0.0, 0.0, 0.0]))
-        elif key == "sublattice":
-            self.atoms.sort(key=lambda atom: atom.sublattice)
         elif isinstance(key, Lattice):
             self._sort_with_other_lattice(key, tolerance)
         else:
             self.atoms.sort(key=key)
         return None
 
-    def find(self, element=None, sublattice=None, position=None, tolerance=None, first=False):
-        """ Search the atom list according to the specified parameters.
+    def find(self, position=None, tolerance=None):
+        """ Search the atom list for an atom at the specified location
 
-        :param element: element name of the atoms to get
-        :param sublattice: sublattice name of the atoms to get
         :param position: position of the atoms to get within a tolerance (can be specified)
         :param tolerance: tolerance of positional search in angstrom.
-        :param first: If set to `True` the first found atom is returned.
-        :return: list of :class:`Atoms <.Atom>` or :class:`Atoms <.Atom>` if first=True or `None` if no atoms satisfy
-                 the criteria.
+        :return: :class:`Atoms <.Atom>` or `None` if no atoms satisfy the criteria.
         """
-        def element_cond(atom):
-            return True if element is None else atom.element == element
 
-        def sublattice_cond(atom):
-            return True if sublattice is None else atom.sublattice == sublattice
+        tolerance = constants.ABS_VEC_COMP_TOL if not tolerance else tolerance
 
-        def position_cond(atom, tol=tolerance):
-            tol = constants.ABS_VEC_COMP_TOL if not tol else tol
-            return True if position is None else self.distance(atom, position) < tol
-
-        found_atoms = (atom for atom in self.atoms
-                       if element_cond(atom)
-                       and sublattice_cond(atom)
-                       and position_cond(atom))
-
-        if first is True:
-            try:
-                return next(found_atoms)
-            except StopIteration:
-                return None
-        else:
-            return list(found_atoms)
+        for atom in self.atoms:
+            if self.distance(atom, position) < tolerance:
+                return atom
 
     def remove(self, atom: Atom):
         """ Removes an atom from the atom list.
@@ -210,7 +183,7 @@ class Lattice:
         :param position: fractional coordinates
         :return: cartesian coordinates
         """
-        position = getattr(position, "position", position)
+        position = self._prepare_position(position, False)
         return self.vectors.dot(np.array(position))
 
     def to_fractional(self, position, periodic=False):
@@ -221,23 +194,23 @@ class Lattice:
                          to a value between 0 and 1.
         :return: fractional coordinates
         """
-        position = getattr(position, "position", position)
+        position = self._prepare_position(position, False)
         frac_position = np.linalg.inv(self.vectors) @ position
         if periodic:
-            return FractionalVector(frac_position).value
+            return PeriodicVector(frac_position).value
         else:
             return frac_position
 
     def get_in_radius(self, center: Union[np.array, list, Atom], max_radius, min_radius=0.0):
         """ Get all :class:`.Atom` that are in range to a provided position.
 
-        :param center: Search center in fractional coordinates. This can either be a list of coordinates or a :class:`.Atom`.
+        :param center: Search center in fractional coordinates. This can either be a coordinates as a list
+                        or a :class:`.Atom`. Mind that positions outside of the cell are placed within.
         :param max_radius: maximal radius in angstrom, that is searched
         :param min_radius: minimal radius in angstrom, that is searched. Default is 0 angstrom.
 
         :return: List of :class:`.Atom`
         """
-
         def condition(atom):
             return min_radius <= self.distance(atom, center) <= max_radius
         atom_list = [atom for atom in self.atoms if condition(atom)]
@@ -251,10 +224,8 @@ class Lattice:
         :param tolerance: Tolerance in angstrom
         :return: index of :class:`.Atom`
         """
-        position = getattr(position, "position", position)
-        position = np.array(getattr(position, "value", position))
-        for i in range(0, len(self.atoms)):
-            if self.distance(self.atoms[i].position, position) < tolerance:
+        for i, atom in enumerate(self.atoms):
+            if self.distance(atom, position) < tolerance:
                 return i
         return None
 
@@ -267,15 +238,6 @@ class Lattice:
         [element_names.add(x.element) for x in self.atoms]
         return list(element_names)
 
-    def get_sublattice_names(self):
-        """ Get all occuring :attr:`Atom.sublattice` names
-
-        :return: List of strings
-        """
-        sublattice_names = set()
-        [sublattice_names.add(x.sublattice) for x in self.atoms]
-        return list(sublattice_names)
-
     def distance(self, position1, position2, periodic=True) -> float:
         """ Get the distance between two points
 
@@ -286,16 +248,12 @@ class Lattice:
         :return: distance in Angstrom
         """
 
-        position1 = getattr(position1, "position", position1)
-        position2 = getattr(position2, "position", position2)
+        position1 = self._prepare_position(position1, periodic)
+        position2 = self._prepare_position(position2, periodic)
 
-        if periodic:
-            position1 = FractionalVector(position1)
-            position2 = FractionalVector(position2)
-            diff_vector = position2.diff(position1)
+        if periodic is True:
+            diff_vector = position1.diff(position2)
         else:
-            position1 = np.array(position1)
-            position2 = np.array(position2)
             diff_vector = position2 - position1
 
         diff_vector_cartesian = diff_vector.dot(self.vectors)
@@ -312,20 +270,14 @@ class Lattice:
         :return: angle in rad
         """
 
-        position1 = getattr(position1, "position", position1)
-        position2 = getattr(position2, "position", position2)
-        center = getattr(center, "position", center)
+        position1 = self._prepare_position(position1, periodic)
+        position2 = self._prepare_position(position2, periodic)
+        center = self._prepare_position(center, periodic)
 
-        if periodic:
-            position1 = FractionalVector(position1)
-            position2 = FractionalVector(position2)
-            center = FractionalVector(center)
-            vec1 = center.diff(position1)
-            vec2 = center.diff(position2)
+        if periodic is True:
+            vec1 = position1.diff(center)
+            vec2 = position2.diff(center)
         else:
-            position1 = np.array(position1)
-            position2 = np.array(position2)
-            center = np.array(center)
             vec1 = position1 - center
             vec2 = position2 - center
 
@@ -352,9 +304,9 @@ class Lattice:
         vertices = [getattr(x, "position", x) for x in vertices]
 
         if periodic is True:
-            vertices = [FractionalVector(x) for x in vertices]
+            vertices = [PeriodicVector(x) for x in vertices]
             reference = vertices[0]
-            vertices = [self.to_cartesian(reference.diff(x)) for x in vertices]
+            vertices = [self.to_cartesian(x.diff(reference)) for x in vertices]
         else:
             vertices = [self.to_cartesian(x) for x in vertices]
 
@@ -380,9 +332,9 @@ class Lattice:
         vertices = [getattr(x, "position", x) for x in vertices]
 
         if periodic is True:
-            vertices = [FractionalVector(x) for x in vertices]
+            vertices = [PeriodicVector(x) for x in vertices]
             reference = vertices[0]
-            vertices = [self.to_cartesian(reference.diff(x)) for x in vertices]
+            vertices = [self.to_cartesian(x.diff(reference)) for x in vertices]
         else:
             vertices = [self.to_cartesian(x) for x in vertices]
 
@@ -399,22 +351,18 @@ class Lattice:
         :param center: fractional coordinates of the center position. Can be a list of coordinates or a :class:`.Atom`.
         :param position: fractional coordinates of the second position. Can be a list of coordinates or a :class:`.Atom`.
         :param rel_increase: distance increase in percent
-        :return: new position as :class:`~crystally.core.vectors.FractionalVector`
+        :return: new position as :class:`~crystally.core.vectors.PeriodicVector`
         """
         # First check if atoms were passed to the function
-        center = getattr(center, "position", center)
-        position = getattr(position, "position", position)
+        center = self._prepare_position(center, True)
+        position = self._prepare_position(position, True)
 
         # check if center and position are identical
         if self.distance(center, position) < constants.ABS_VEC_COMP_TOL:
             raise ValueError("Center and Position are too close together")
 
-        # Now convert the vectors to ensure periodicity
-        center = FractionalVector(center)
-        position = FractionalVector(position)
-
         # calculate the distance in fractional coordinates from center to position
-        diff_vector = center.diff(position)
+        diff_vector = position.diff(center)
 
         # convert everything to cartesian coordinates
         center = self.vectors.dot(center.value)
@@ -424,7 +372,7 @@ class Lattice:
         new_position = center + diff_vector * (1+rel_increase)
 
         # convert the new position to fractional coordinates
-        return FractionalVector(np.linalg.inv(self.vectors).dot(new_position))
+        return PeriodicVector(np.linalg.inv(self.vectors).dot(new_position))
 
     def increase_distance_abs(self, center, position, abs_increase):
         """ Function to easily manipulate lattices. A center and second position need to be provided. The second
@@ -434,7 +382,7 @@ class Lattice:
         :param center: fractional coordinates of the center position. Can be a list of coordinates or a :class:`.Atom`.
         :param position: fractional coordinates of the second position. Can be a list of coordinates or a :class:`.Atom`.
         :param abs_increase: Shift in angstrom
-        :return: new position as :class:`~crystally.core.vectors.FractionalVector`
+        :return: new position as :class:`~crystally.core.vectors.PeriodicVector`
         """
         distance = self.distance(center, position)
         rel_distance = abs_increase/distance
@@ -469,7 +417,7 @@ class Lattice:
         return self_not_found, other_not_found
 
     def _sort_with_other_lattice(self, other, tolerance=None):
-        if not tolerance:
+        if tolerance is None:
             tolerance = constants.ABS_VEC_COMP_TOL
 
         old_order = list(self.atoms)
@@ -485,12 +433,24 @@ class Lattice:
     def _compare_atoms(self, atom1, atom2, dist_tolerance):
         if atom1.element != atom2.element:
             return False
-        if atom1.sublattice != atom2.sublattice:
-            return False
         if self.distance(atom1, atom2) > dist_tolerance:
             return False
         return True
 
+    def _prepare_position(self, position, periodic):
+        """ Helper function to prepare positions, which were given as arguments.
+
+        :param position: Either an Atom or a Vector (e.g. list / np.array / PeriodicVector)
+        :param periodic: decides if an PeriodicVector or an np.array is returned
+        :return:
+        """
+        position = getattr(position, "position", position)
+        if periodic is True:
+            position = PeriodicVector(position)
+        else:
+            position = np.array(position)
+        return position
+
     @staticmethod
     def from_lattice(lattice, size_x: int = 1, size_y: int = 1, size_z: int = 1):
         """ Create a new lattice with an already existing one. You can also provide size values to expand the lattice.
@@ -505,11 +465,10 @@ class Lattice:
         new_lattice_size = np.array([size_x, size_y, size_z])
         new_lattice_positions = []
 
-        def reorientate_position(pos, x, y, z): return FractionalVector((pos + np.array([x, y, z])) / new_lattice_size)
+        def reorientate_position(pos, x, y, z): return PeriodicVector((pos + np.array([x, y, z])) / new_lattice_size)
 
         lattice_expansion = ((x, y, z) for x in range(size_x) for y in range(size_y) for z in range(size_z))
         new_lattice_positions += [Atom(element=atom.element,
-                                       sublattice=atom.sublattice,
                                        position=reorientate_position(atom.position.value, *coord))
                                   for coord in lattice_expansion for atom in lattice.atoms]
 
@@ -518,24 +477,6 @@ class Lattice:
         new_lattice.sort("element")
         return new_lattice
 
-    @staticmethod
-    def grid_atoms(lattice, grid_step):
-
-        def to_grid(lattice, position, round_func):
-            position = lattice.vectors @ position
-            return tuple(int(x) for x in round_func(np.round(position / grid_step, 10)))
-
-        grid_size = to_grid(lattice, np.array([1, 1, 1]), np.ceil)
-
-        grid = [[[[] for _ in range(grid_size[2])]
-                     for _ in range(grid_size[1])]
-                     for _ in range(grid_size[0])]
-
-        for atom in lattice:
-            x, y, z = to_grid(lattice, atom.position, np.floor)
-            grid[x][y][z].append(atom)
-        return grid
-
 
 def concat_lattices(lattice1: Lattice, lattice2: Lattice, direction: int):
     for i in range(lattice1.vectors.shape[0]):
@@ -548,7 +489,7 @@ def concat_lattices(lattice1: Lattice, lattice2: Lattice, direction: int):
     new_lattice.vectors[direction] = lattice1.vectors[direction] + lattice2.vectors[direction]
     for atom in lattice1.atoms:
         new_atom = copy.copy(atom)
-        new_atom.position = FractionalVector(atom.position.value.dot(lattice1.vectors).dot(np.linalg.inv(new_lattice.vectors)))
+        new_atom.position = PeriodicVector(atom.position.value.dot(lattice1.vectors).dot(np.linalg.inv(new_lattice.vectors)))
         new_lattice.atoms.append(new_atom)
 
     for atom in lattice2.atoms:
@@ -558,7 +499,7 @@ def concat_lattices(lattice1: Lattice, lattice2: Lattice, direction: int):
         shift_cart = shift.dot(lattice1.vectors)
         new_position = new_atom.position.value.dot(lattice2.vectors) + shift_cart
         new_position = new_position.dot(np.linalg.inv(new_lattice.vectors))
-        new_atom.position = FractionalVector(new_position)
+        new_atom.position = PeriodicVector(new_position)
         new_lattice.atoms.append(new_atom)
 
     return new_lattice
