@@ -1,58 +1,55 @@
 import numpy as np
-import crystally.core.constants as const
 
-__all__ = ["FractionalVector"]
+__all__ = ["PeriodicVector"]
 
 
-class FractionalVector:
-    r"""A point in fractional space - e.g. in a crystal system.
+class PeriodicVector:
+    r"""A point i periodic enironment - e.g. in a crystal system.
 
-    A fractional vector has three coordinates in range [0, 1). The fractional vector space is periodic, meaning
-    that values greater or equal to one can be reduced: 1.1 == 0.1 and -0.2 == 0.8
-    This class is only a wrapper for the numpy array which checks the coordinates and the shape of the array. To access
-    the numpy array use :meth:`value`.
+    A periodic vector has three coordinates in range [0, 1). The periodic vector space only has fractional entries,
+    meaning that values greater or equal to 1 or smaller than 0 can be reduced: 1.1 == 0.1 and -0.2 == 0.8
+    This class is a wrapper of a numpy. To access the array use :meth:`value`.
 
-    :param vector: vector like container
-    :return: FractionalVector with altered coordinates
+    :param vector: list of numerals
+    :return: PeriodicVector with fractional coordinates
 
     Examples
     --------
-    >>> FractionalVector([1.0, 0.1, -0.6])
-    FractionalVector([0.0, 0.1, 0.4])
+    >>> PeriodicVector([1.0, 0.1, -0.6])
+    PeriodicVector([0.0, 0.1, 0.4])
 
     """
 
     def __init__(self, vector):
         vector = getattr(vector, "value", vector)
+        if len(vector) != 3:
+            raise ValueError("PeriodicVector must have a dimension of 3!")
         self.__value = np.array(vector) % 1.0
 
     def __add__(self, other):
         other = getattr(other, "value", other)
-        new_vec = FractionalVector(self.value + np.array(other))
+        new_vec = PeriodicVector(self.value + other)
         return new_vec
 
     def __sub__(self, other):
-        return self + other*-1
+        other = getattr(other, "value", other)
+        new_vec = PeriodicVector(self.value - other)
+        return new_vec
 
     def __truediv__(self, other: float):
-        new_vec = FractionalVector(self.value / other)
+        new_vec = PeriodicVector(self.value / other)
         return new_vec
 
     def __mul__(self, other):
         other = getattr(other, "value", other)
-        new_vec = FractionalVector(self.value * np.array(other))
+        new_vec = PeriodicVector(self.value * other)
         return new_vec
 
-    def __round__(self, n=None):
-        if not n:
-            n = const.VEC_ROUNDING
-        return FractionalVector([n * round(x/n) for x in self])
-
     def __str__(self):
         return str(self.value)
 
     def __repr__(self):
-        return "FractionalVector({})".format(self.value.tolist())
+        return "PeriodicVector({})".format(self.value.tolist())
 
     def __getitem__(self, item):
         return self.value[item]
@@ -60,14 +57,6 @@ class FractionalVector:
     def __len__(self):
         return len(self.value)
 
-    def __hash__(self):
-        return hash(tuple(round(self).tolist()))
-
-    def __eq__(self, other):
-        rounded1 = tuple(tuple(round(self).tolist()))
-        rounded2 = tuple(tuple(round(other).tolist()))
-        return rounded1 == rounded2
-
     @property
     def value(self):
         """ Get the wrapped numpy array
@@ -78,13 +67,13 @@ class FractionalVector:
 
     @value.setter
     def value(self, vec):
-        raise TypeError("FractionalVector is immutable")
+        raise TypeError("PeriodicVector is immutable")
 
     @property
     def x(self):
         """ Get the x component of this vector, is identical to vec[0]
 
-        :return: depends on the entry in the vector (probably a float)
+        :return: x scalar
         """
         if len(self) < 1:
             raise IndexError("This vector does not have a x component.")
@@ -94,7 +83,7 @@ class FractionalVector:
     def y(self):
         """ Get the y component of this vector, is identical to vec[0]
 
-        :return: depends on the entry in the vector (probably a float)
+        :return: y scalar
         """
         if len(self) < 2:
             raise IndexError("This vector does not have a y component.")
@@ -104,7 +93,7 @@ class FractionalVector:
     def z(self):
         """ Get the z component of this vector, is identical to vec[0]
 
-        :return: depends on the entry in the vector (probably a float)
+        :return: z scalar
         """
         if len(self) < 3:
             raise IndexError("This vector does not have a z component.")
@@ -118,25 +107,25 @@ class FractionalVector:
         return self.value.tolist()
 
     def diff(self, other):
-        """ Get the minimal distance between two FractionalVector
+        """ Get the difference vector between this PeriodicVector and another point.
 
         :param other: vector like container
         :return: 1xN numpy array where N is the dimension of the vectors
 
         Examples
         --------
-        >>> FractionalVector([0.2, 0, 0]).diff([0, 0, 0.2])
+        >>> PeriodicVector([0.2, 0, 0]).diff([0, 0, 0.2])
         array([-0.2,  0. ,  0.2])
 
-        >>> vec1 = FractionalVector([0.5, 0.5, 0.5])
-        >>> vec2 = FractionalVector([0.6, 0.7, 0.8])
-        >>> vec1.diff(vec2)
-        array([0.1,  0.2 ,  0.3])
+        >>> vec1 = PeriodicVector([0.5, 0.5, 0.5])
+        >>> vec2 = PeriodicVector([0.6, 0.7, 0.8])
         >>> vec2.diff(vec1)
+        array([0.1,  0.2 ,  0.3])
+        >>> vec1.diff(vec2)
         array([-0.1,  -0.2 ,  -0.3])
         """
-        other = FractionalVector(other)
-        vec = np.array(other.value) - self.value
+        other = PeriodicVector(other)
+        vec = self.value - np.array(other.value)
         return np.array([_min_periodic_distance(c) for c in vec])
 
 
